@@ -10,4 +10,10 @@ use Data::TreeDumper;
 
 my $tv = WWW::AtMovies::TV->new;
 print DumpTree($tv->now);
+my %now = $tv->now;
+
+print DumpTree(\%now);
 print DumpTree($tv->next);
+
+my %next = $tv->next;
+print DumpTree(\%next);
